# pysoleng

pysoleng is a package designed to study solar energy and its applications. 

# What can it do now?

- Describe positions and surfaces on Earth (all continents);
- Identify the position of the sun over time;
- Calculate the direct radiation incidence angle on a flat surface;
- Estimate how much insolation reaches a given surface on Earth.

# Milestones

It would be interesting to add the following features to the package:

1) The ability to use other models for sloped surface radiation calculations, such as the anisotropic sky model;

2) The ability to estimate the performance of key solar energy technologies, namely solar thermal (ST) and photovoltaics (PV), using different models;

3) The ability to estimate parameters for solar thermal collector models.

# Bibliography

The following publications were relied upon:

- John A. Duffie, William A. Beckman, Solar Engineering of Thermal Processes, Fourth Edition, John Wiley & Sons, 2013. DOI: 10.1002/9781118671603
- Jean Meeus, Astronomical Algorithms, Second Edition, Willmann-Bell, 1998. ISBN: 978-0943396613
- Soteris Kalogirou, Solar Energy Engineering: Processes and Systems, First Edition, 2009. DOI: 10.1016/B978-0-12-374501-9.X0001-5
- Soteris Kalogirou, Solar Energy Engineering: Processes and Systems, Second Edition, 2013. DOI: 10.1016/C2011-0-07038-2